"""
Copyright (c) 2026 RetrievalLabs Co. All rights reserved.
Licensed under the Apache License, Version 2.0.
"""

from .adapter import OpenAIQueryEmbeddingAdapter

__all__ = ["OpenAIQueryEmbeddingAdapter"]
